@@ -25,7 +25,6 @@ import sentry_sdk
 from fastapi.encoders import jsonable_encoder
 from integrations import cpr_mapper
 from integrations.ad_integration import ad_reader
-from integrations.calculate_primary.common import LOGGER_NAME
 from integrations.calculate_primary.common import NoPrimaryFound
 from integrations.calculate_primary.sd import SDPrimaryEngagementUpdater
 from integrations.rundb.db_overview import DBOverview
@@ -64,33 +63,11 @@ from .skip import cpr_env_filter
 from .sync_job_id import JobIdSync
 
 
-LOG_LEVEL = logging.DEBUG
 DUMMY_CPR = "0000000000"
 
 logger = logging.getLogger("sdChangedAt")
 
 
-def setup_logging(log_file: pathlib.Path):
-    detail_logging = (
-        "sdCommon",
-        "sdChangedAt",
-        LOGGER_NAME,
-        "fixDepartments",
-        "sdSyncJobId",
-    )
-    for name in logging.root.manager.loggerDict:
-        if name in detail_logging:
-            logging.getLogger(name).setLevel(LOG_LEVEL)
-        else:
-            logging.getLogger(name).setLevel(logging.ERROR)
-
-    logging.basicConfig(
-        format="%(levelname)s %(asctime)s %(name)s %(message)s",
-        level=LOG_LEVEL,
-        filename=str(log_file),
-    )
-
-
 # TODO: SHOULD WE IMPLEMENT PREDICTABLE ENGAGEMENT UUIDS ALSO IN THIS CODE?!?
 
 
@@ -122,11 +99,6 @@ class ChangeAtSD:
         self.skip_job_functions = self.settings.sd_skip_job_functions
         self.use_ad = self.settings.sd_use_ad_integration
 
-        # TODO: remove when MO is updated to a version greater than 2.7.0
-        self.terminate_engagement_with_to_only = (
-            self.settings.sd_terminate_engagement_with_to_only
-        )
-
         # See https://os2web.atlassian.net/browse/MO-245 for more details
         # about no_salary_minimum
         self.no_salary_minimum = self.settings.sd_no_salary_minimum_id
@@ -772,8 +744,7 @@ class ChangeAtSD:
 
             if cpr != activation_date_info["PersonCivilRegistrationIdentifier"]:
                 logger.error(
-                    "wrong cpr %r for position %r at date %r",
-                    activation_date_info["PersonCivilRegistrationIdentifier"],
+                    "wrong cpr for position %r at date %r",
                     engagement["EmploymentIdentifier"],
                     status["ActivationDate"],
                 )
@@ -896,12 +867,7 @@ class ChangeAtSD:
             logger.warning(f"Terminating non-existing job: {user_key}!")
             return False
 
-        # TODO: remove this hack when MO is updated to a version greater
-        #  than 2.7.0 !!
-
         validity = {"from": from_date, "to": to_date}
-        if self.terminate_engagement_with_to_only:
-            validity = {"to": sd_to_mo_termination_date(from_date)}
 
         # TODO: use/create termination object from RA Models
         payload = {
@@ -1197,7 +1163,11 @@ class ChangeAtSD:
             code = EmploymentStatus(code)
 
             if code == EmploymentStatus.AnsatUdenLoen:
-                logger.info("Status 0. Cpr: {}, job: {}".format(cpr, employment_id))
+                logger.info(
+                    "Status 0. Cpr: {}, job: {}".format(
+                        f"{cpr[:6]}-xxxx", employment_id
+                    )
+                )
                 mo_eng = self._find_engagement(employment_id, person_uuid)
                 if mo_eng:
                     logger.info("Status 0, edit eng {}".format(mo_eng["uuid"]))
@@ -1249,7 +1219,9 @@ class ChangeAtSD:
             elif code in EmploymentStatus.let_go():
                 sd_from_date = status["ActivationDate"]
                 sd_to_date = status["DeactivationDate"]
-                logger.info("Terminate {}, job_id {} ".format(cpr, employment_id))
+                logger.info(
+                    "Terminate {}, job_id {} ".format(f"{cpr[:6]}-xxxx", employment_id)
+                )
                 success = self._terminate_engagement(
                     user_key=employment_id,
                     person_uuid=person_uuid,
@@ -1327,7 +1299,7 @@ class ChangeAtSD:
             sd_employments = ensure_list(employment["Employment"])
 
             logger.info("---------------------")
-            logger.info("We are now updating {}".format(cpr))
+            logger.info("We are now updating {}".format(f"{cpr[:6]}-xxxx"))
             logger.debug("From date: {}".format(self.from_date))
             logger.debug("To date: {}".format(self.to_date))
             logger.debug("Employment: {}".format(employment))
@@ -1462,7 +1434,7 @@ def changed_at_cli(init: bool, force: bool, from_date: datetime.datetime):
 def changed_at(init: bool, force: bool, from_date: Optional[datetime.datetime] = None):
     """Tool to delta synchronize with MO with SD."""
     settings = get_changed_at_settings()
-    setup_logging(settings.sd_log_file)
+    settings.start_logging_based_on_settings()
 
     run_db = settings.sd_import_run_db
 
